//do-file for "Multilevel analysis"
//use Lab1_ESS5.dta

tab cntry

encode cntry, g(country)                          //this variable exists in the dataset

mixed political_trust || country:, ml variance    //empty multilevel model

estat icc                                         //intraclass correlation

mixed political_trust woman age unemployed eduyrs || country:, ml variance //random intercept model

merge m:1 country using GDPcapita.dta                                  //this variable exists in the dataset

mixed political_trust woman age unemployed eduyrs GDPcapita1000 || country:, ml variance //random intercept model with level-2 variable

sum political_trust woman age unemployed eduyrs if e(sample)	//produce descriptive statistics for level-1 variables

bysort country: gen byte Level2Mark=_n==1
sum GDPcapita1000 if Level2Mark==1				//produce descriptive statistics for level-2 variable


//use Lab2_ESS.dta

melogit vote age woman Nordic || Level2:, //logistic multilevel model

melogit vote age woman Nordic || Level2:, intmethod(laplace)  //logistic model with Laplacian approximation

//use Lab1_ESS5.dta

mixed political_trust woman age unemployed eduyrs GDPcapita1000 || country: eduyrs, ml variance //random coefficient model

mixed political_trust woman age unemployed eduyrs GDPcapita1000 || country: eduyrs, cov(unstructured) ml variance //random coefficient model

qui mixed political_trust woman age unemployed eduyrs GDPcapita1000 || country:, ml variance //-2 Log Likelihood test
estimates store ri
qui mixed political_trust woman age unemployed eduyrs GDPcapita1000 || country: eduyrs, ml variance 
estimates store rc
lrtest ri rc

mixed political_trust woman age unemployed eduyrs GDPcapita1000 Nordic Nordicage || country:, ml variance //random intercept model including cross-level interaction term

sum political_trust if e(sample)                                 //finding descriptive statistics for our dependent, including only units present in our last model

gen L1=10.27438+0.0097856*age+4.041631*1-0.0262395*1*age
gen L2=10.27438+0.0097856*age+4.041631*0-0.0262395*0*age
graph twoway (mspline L1 age, ytitle("Political trust") lpattern(solid)) (mspline L2 age, lpattern(longdash)), legend(label(1 "Nordic countries") label(2 "Other countries"))    //conditional effect plot


qui mixed political_trust woman unemployed eduyrs GDPcapita1000 i.Nordic##c.age || country:, ml variance
margins, at(age=(14(1)102) Nordic=( 0 1))
marginsplot                                                       //margins plot for the interaction

//use Lab3_ESS5.dta

egen Level2 = group(Level3 essround)                             //generating level-2 identifier

merge m:1 Level2 using GDPcapitaLevel3.dta						//this variable exists in the dataset

mixed political_trust || Level3:, || Level2:, ml variance     //three-level empty model

mixed political_trust woman age unemployed eduyrs GDPcapita1000 Nordic || Level3: || Level2:, ml variance    //Three-level model

//use Lab4_ESS.dta

melogit vote age woman GDPcapita1000 Nordic || Level3: || Level2:, intmethod(laplace) //Three-level logistic model with Laplacian approximation


//use Lab1_ESS.dta

quietly levelsof cntry                                         
local numctry: word count `r(levels)'
quietly count if missing(cntry)
local cntpercntry = (_N-r(N))/`numctry'
bys cntry: gen sample_weight = `cntpercntry' / _N if !missing(cntry)

gen designsample=dweight*sample_weight                  

mixed political_trust woman age unemployed eduyrs GDPcapita1000 [pw=designsample] || country:, ml variance   //two-level model including weights

quietly mixed political_trust woman age unemployed eduyrs GDPcapita1000 || country:, ml variance
predict resid if e(sample), residuals					//predict level-1 residuals
histogram resid, normal									//produce histogram of level-1 residuals 
qnorm resid												//Q-Q plot of level-1 residuals

quietly mixed political_trust woman age unemployed eduyrs GDPcapita1000 || country:, ml variance
predict re* if e(sample), reff							//predict level-2 residuals
bysort country (re1): gen byte countrymark = _n == 1	//generating groups
histogram re1 if countrymark, normal					//produce histogram of level-2 residuals
qnorm re1 if countrymark								//Q-Q plot of level-2 residuals

drop resid re1 countrymark

quietly mixed political_trust woman age unemployed eduyrs GDPcapita1000 || country:, ml variance
predict ptrust if e(sample)
predict resid if e(sample), residuals
predict re* if e(sample), reff
bysort country (re1): gen byte countrymark = _n == 1
scatter resid ptrust									//level-1 heteroskedasticity
scatter re1 ptrust if countrymark						//level-2 heteroskedasticity 

quietly regress political_trust woman age unemployed eduyrs GDPcapita1000
estat vif												//test for multicollienarity

mixed political_trust woman age unemployed eduyrs GDPcapita1000 || country:, ml variance
predict u* if e(sample), reffects						//generate new variable for the group level error of the intercept
bysort country: generate groups = (_n==1)
list country u1 if groups								//level-2 deviations from the mean intercept 

drop u1 groups
mixed political_trust woman age unemployed eduyrs GDPcapita1000 || country: eduyrs, ml variance
predict u* if e(sample), reffects
bysort country: generate groups=(_n==1)
list country u1 u2 if groups							//level-2 deviations from mean intercept and random slope

gen intercept = _b[_cons] + u2
gen slope = _b[eduyrs] + u1
list country intercept slope if groups					//intercept and slope for each country on eduyrs 
gen yhat = intercept + (slope*eduyrs)
twoway line yhat eduyrs if country==1					//graph for country #1
twoway line yhat eduyrs if country<=25					//graph for all countries
drop u1 u2 groups intercept slope yhat ptrust resid re1 countrymark

ssc install mlt.pkg										//install the MLT package
xtmixed political_trust woman age unemployed eduyrs GDPcapita1000 || country:, ml variance
mltrsq													//Snijders and Boskers and Raudenbush and Raudenbush R-squared
mltl2scatter political_trust GDPcapita1000, l2id(country)	//scatter plot for upper level 
mltl2scatter political_trust age, l2id(country)			//mean levels of independent and dependent

quietly xtmixed political_trust woman age unemployed eduyrs GDPcapita1000 || country:, ml variance
mltcooksd												//Cook's distance values above 4/N for upper level
mltcooksd, graph										//Graph of DFBETAs




